@@ -1,10 +1,11 @@
+import os
 import sys
 import logging
 import argparse
 from typing import List
 from sklearn import cluster, metrics
 from .query_cluster import EvaluationScore, QueryClusterModel, EstimatorElem
-from .query_cluster import Sentence2Vector, QueryClusterCoach
+from .query_cluster import Sentence2Vector, QueryClusterCoach, QueryClusterPredictor
 
 
 class QueryClusterCoachOPTICS(QueryClusterCoach):
@@ -68,18 +69,24 @@ class QueryClusterCoachOPTICS(QueryClusterCoach):
 
 
 def main():
+    local_path = "/".join(os.path.abspath(__file__).split("/")[:-1])
     log_format_string = '%(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s'
     logging.basicConfig(level=logging.INFO, format=log_format_string, stream=sys.stderr)
     parser = argparse.ArgumentParser()
-    parser.add_argument("queries_file", type=str, help="Query file", default="queries.txt")
-    parser.add_argument("model_file", type=str, help="Model file", default="model.pkl")
+    parser.add_argument(
+        "--queries_file", type=str, help="短文本文件默认demo数据", default=local_path + "/demo/queries.txt"
+    )
+    parser.add_argument(
+        "--model_file", type=str, help="生成的模型文件默认存储在demo路径下", default=local_path + "/demo/model.pkl"
+    )
     # 实验次数(实验次数影响聚类结果的每个cluster中最小样本数量)
-    parser.add_argument("--max_exp_count", type=int, help="最大实验次数", default=8, required=False)
+    parser.add_argument("--max_exp_count", type=int, help="最大实验次数默认8", default=8, required=False)
     args = parser.parse_args()
 
     with open(args.queries_file, "r") as fp:
         queries = [line.strip("\r\n") for line in fp.readlines()]
 
+    logging.info("Start to train cluster model with demo data")
     QueryClusterCoachOPTICS(
         sent2vec=Sentence2Vector(),
         model=QueryClusterModel(),
@@ -87,6 +94,18 @@ def main():
         max_exp_count=args.max_exp_count
     ).train(queries=queries, saved_model=args.model_file)
 
+    logging.info("Inference result")
+    predictor = QueryClusterPredictor(
+        sent2vec=Sentence2Vector(),
+        model=QueryClusterModel(),
+        model_file=args.model_file
+    )
+    outputs = []
+    for index, query in enumerate(queries):
+        label = predictor.inference(query)
+        outputs.append(str(label) + "\t" + query)
+    print("\n".join(outputs))
+
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
