@@ -166,13 +166,13 @@ class QueryClusterPredictor(object):
         :param query:
         :return:
         """
-        logging.info("Inference query label")
+        logging.debug("Inference query label")
         if self.best_model.matrix is None:
             logging.error("No model loaded train/load first")
             raise ValueError("No model loaded train/load first")
 
         if query in self.best_model.queries:
-            logging.info("Query in model %s" % query)
+            logging.debug("Query in model %s" % query)
             return self.best_model.score.labels[self.best_model.queries.index(query)]
 
         vector = self.__sent2vec.encoding(queries=[query])
